using System;
using System.Data;
using System.Configuration;
using System.Globalization;
using System.Collections;

using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using Castle.Facilities.NHibernateIntegration;
using Castle.Services.Transaction;

using NHibernate;

using Cuyahoga.Core.Domain;
using Cuyahoga.Modules.Company.Domain;

namespace Cuyahoga.Modules.Company.DataAccess
{
    /// <summary>
    /// Specific Data Access functionality for Company module.
    /// NOTE: Set the 'Delete Rule' and 'Update Rule' on the relationships between tables (in the Database Diagrams): Database Designer: Update and Delete Specification
    /// </summary>
    [Transactional]
    public class CompanyDao : Cuyahoga.Modules.Company.DataAccess.ICompanyDao
    {

        private ISessionManager _sessionManager;

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="sessionManager"></param>
        public CompanyDao(ISessionManager sessionManager)
	    {
	        this._sessionManager = sessionManager;
        }

        #region Employee Data Access
            public IList GetEmployees()
            {
                try
                {
                    string hql = "select c from Cuyahoga.Modules.Company.Domain.Employee c";
                    IQuery q = this._sessionManager.OpenSession().CreateQuery(hql);
                    //q.SetInt32("siteId", site.Id);
                    return q.List();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not get the 'Employee' object list: " + x.Message);
                }
            }

            public Employee GetEmployee(int employeeID)
            {
                try
                {
                    string hql = "select c from Cuyahoga.Modules.Company.Domain.Employee c where c.Id = :EmployeeID";
                    IQuery q = this._sessionManager.OpenSession().CreateQuery(hql);
                    q.SetInt32("EmployeeID", employeeID);
                    return q.List()[0] as Employee;
                }
                catch (Exception x)
                {
                    throw new Exception("Could not get the 'Employee object: " + x.Message);
                }
            }

            public void SaveEmployee(Employee employeeToSave)
            {
                try
                {
                    ISession currentSession = this._sessionManager.OpenSession();
                    currentSession.SaveOrUpdate(employeeToSave);
                    currentSession.Flush();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not save the 'Employee object: " + x.Message);
                }
            }

            public void SaveOrUpdateEmployee(Employee employeeToSave)
            {
                try
                {
                    ISession currentSession = this._sessionManager.OpenSession();
                    currentSession.SaveOrUpdate(employeeToSave);
                    currentSession.Flush();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not save the 'Employee object: " + x.Message);
                }
            }

            public void DeleteEmployee(Employee employeeToDelete)
            {
                try
                {
                    ISession currentSession = this._sessionManager.OpenSession();
                    currentSession.Delete(employeeToDelete);
                    currentSession.Flush();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not delete the 'Employee object: " + x.Message);
                }
            }
        #endregion Employee Data Access

            #region Department Data Access
            public IList GetDepartments()
            {
                try
                {
                    string hql = "select c from Cuyahoga.Modules.Company.Domain.Department c";
                    IQuery q = this._sessionManager.OpenSession().CreateQuery(hql);
                    //q.SetInt32("siteId", site.Id);
                    return q.List();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not get the 'Department' object list: " + x.Message);
                }
            }

            public Department GetDepartment(int departmentID)
            {
                try
                {
                    string hql = "select c from Cuyahoga.Modules.Company.Domain.Department c where c.Id = :DepartmentID";
                    IQuery q = this._sessionManager.OpenSession().CreateQuery(hql);
                    q.SetInt32("DepartmentID", departmentID);
                    return q.List()[0] as Department;
                }
                catch (Exception x)
                {
                    throw new Exception("Could not get the 'Department object: " + x.Message);
                }
            }

            public void SaveDepartment(Department departmentToSave)
            {
                try
                {
                    ISession currentSession = this._sessionManager.OpenSession();
                    currentSession.SaveOrUpdate(departmentToSave);
                    currentSession.Flush();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not save the 'Department object: " + x.Message);
                }
            }

            public void SaveOrUpdateDepartment(Department departmentToSave)
            {
                try
                {
                    ISession currentSession = this._sessionManager.OpenSession();
                    currentSession.SaveOrUpdate(departmentToSave);
                    currentSession.Flush();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not save the 'Department object: " + x.Message);
                }
            }

            public void DeleteDepartment(Department departmentToDelete)
            {
                try
                {
                    ISession currentSession = this._sessionManager.OpenSession();
                    currentSession.Delete(departmentToDelete);
                    currentSession.Flush();
                }
                catch (Exception x)
                {
                    throw new Exception("Could not delete the 'Department object: " + x.Message);
                }
            }
            #endregion Department Data Access

    }
}
